summaryrefslogtreecommitdiffstats
path: root/bibletime/frontend/manageindicesform.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-17 17:31:58 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-17 17:31:58 +0000
commitb6027ae3f71e2c1961357500b9da203e3a04a194 (patch)
treef6e7cbb9ad81542a6287c7c60602d5a38cf24457 /bibletime/frontend/manageindicesform.cpp
parent1ed307edd091effc390a7b98986fccb0f8307582 (diff)
downloadbibletime-b6027ae3f71e2c1961357500b9da203e3a04a194.tar.gz
bibletime-b6027ae3f71e2c1961357500b9da203e3a04a194.zip
TQt4 port Bibletime
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/bibletime@1232459 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'bibletime/frontend/manageindicesform.cpp')
-rw-r--r--bibletime/frontend/manageindicesform.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/bibletime/frontend/manageindicesform.cpp b/bibletime/frontend/manageindicesform.cpp
index c711876..1be9052 100644
--- a/bibletime/frontend/manageindicesform.cpp
+++ b/bibletime/frontend/manageindicesform.cpp
@@ -21,18 +21,18 @@
#include <tqwhatsthis.h>
/*
* Constructs a ManageIndicesForm as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-ManageIndicesForm::ManageIndicesForm( TQWidget* parent, const char* name, WFlags fl )
- : TQWidget( parent, name, fl )
+ManageIndicesForm::ManageIndicesForm( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "ManageIndicesForm" );
ManageIndicesFormLayout = new TQVBoxLayout( this, 0, 8, "ManageIndicesFormLayout");
m_labelFrame = new TQFrame( this, "m_labelFrame" );
- m_labelFrame->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)5, 0, 0, m_labelFrame->sizePolicy().hasHeightForWidth() ) );
+ m_labelFrame->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)5, 0, 0, m_labelFrame->sizePolicy().hasHeightForWidth() ) );
m_labelFrame->setFrameShape( TQFrame::NoFrame );
m_labelFrame->setFrameShadow( TQFrame::Plain );
ManageIndicesFormLayout->addWidget( m_labelFrame );
@@ -43,18 +43,18 @@ ManageIndicesForm::ManageIndicesForm( TQWidget* parent, const char* name, WFlags
m_moduleList = new KListView( this, "m_moduleList" );
ManageIndicesFormLayout->addWidget( m_moduleList );
- layout1 = new TQHBoxLayout( 0, 0, 6, "layout1");
+ tqlayout1 = new TQHBoxLayout( 0, 0, 6, "tqlayout1");
spacer1 = new TQSpacerItem( 40, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
- layout1->addItem( spacer1 );
+ tqlayout1->addItem( spacer1 );
m_createIndicesButton = new TQPushButton( this, "m_createIndicesButton" );
- layout1->addWidget( m_createIndicesButton );
+ tqlayout1->addWidget( m_createIndicesButton );
m_deleteIndicesButton = new TQPushButton( this, "m_deleteIndicesButton" );
- layout1->addWidget( m_deleteIndicesButton );
- ManageIndicesFormLayout->addLayout( layout1 );
+ tqlayout1->addWidget( m_deleteIndicesButton );
+ ManageIndicesFormLayout->addLayout( tqlayout1 );
languageChange();
- resize( TQSize(415, 404).expandedTo(minimumSizeHint()) );
+ resize( TQSize(415, 404).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
}
@@ -63,7 +63,7 @@ ManageIndicesForm::ManageIndicesForm( TQWidget* parent, const char* name, WFlags
*/
ManageIndicesForm::~ManageIndicesForm()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -21,18 +21,18 @@
#include <tqwhatsthis.h>
/*
- * Constructs a ManageIndicesForm as a child of 'parent', with the
+ * Constructs a ManageIndicesForm as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/